psychosnd
===============================

version number: 0.0.1
author: Gavin Cooper

Overview
--------

Psychopy sound analysis scripts

Installation / Usage
--------------------

To install use pip:

    $ pip install psychosnd

If you have a local version you can also use:

    $ pip install <path_to_package>/psychosnd-0.0.1.tar.gz

Contributing
------------

TBD

Example
-------

TBD
